@@ -54,3 +54,6 @@
 
 /* Define to the signed 16 bit type*/
 #undef int16_t
+
+/* Define if you want to use the Debian upgrade process */
+#undef DACT_DEBIAN_UPGRADE_PROC
