@@ -1,3 +1,23 @@
+/*
+ * Copyright (C) 2001  Roy Keene
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *
+ *      email: dact@rkeene.org 
+ */
+
 #ifndef _ALGORITHMS_H
 #define _ALOGIRTHMS_H
 /*
@@ -18,12 +38,12 @@
 #endif
 #ifdef DEBUG
 #include "comp_factor.h"
+#include "comp_bitsums.h"
 #endif
 #include "comp_range.h"
 #include "comp_snibble.h"
 #include "comp_text.h"
 #include "comp_fail.h"
-#include "comp_bitsums.h"
 
 #ifdef __DACT_C
 int (*(algorithms[256]))()={    comp_plain_algo,
@@ -86,7 +106,7 @@ int (*(algorithms[256]))()={    comp_plain_algo,
 				NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL,
 				NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL,
 				NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL,
-				NULL, NULL, NULL,
+				NULL, NULL, 
                                 NULL};
 
 char *algorithm_names[256]={	"Uncompressed",
