@@ -355,10 +355,8 @@ uint32_t dact_process_other(int src, const int dest, const uint32_t magic, const
 	gzFile gzfd;
 #endif
 
-
 	filesize=0;  /* Fix a warning, that is all. */
 
-
 /*
  * bad and broke stuff XXX FIXME XXX FIXME XXX FIXME
  * There has to be a better way to do this... I just want
@@ -558,7 +556,6 @@ uint32_t dact_process_file(const int src, const int dest, const int mode, const
 		if (cipher!=-1) {
 			dact_hdr_ext_regn(DACT_HDR_CIPHER, cipher, sizeof(cipher));
 			keybuf=malloc(DACT_KEY_SIZE);
-
 			ciphers[cipher](NULL, NULL, 0, keybuf, DACT_MODE_CINIT+DACT_MODE_CENC);
 			
 		}
@@ -658,7 +655,7 @@ uint32_t dact_process_file(const int src, const int dest, const int mode, const
 			write_de(dest, blk_cnt, 4);
 		} 
 
-		if (lseek_net(dest, 24, SEEK_SET)>0) {
+		if (lseek_net(dest, DACT_HDR_REG_SIZE, SEEK_SET)>0) {
 			if (!options[DACT_OPT_NOCRC]) {
 				dact_hdr_ext_regn(DACT_HDR_CRC0, crcs[0], 4);
 				dact_hdr_ext_regn(DACT_HDR_CRC1, crcs[1], 4);
@@ -677,7 +674,7 @@ uint32_t dact_process_file(const int src, const int dest, const int mode, const
 
 		dact_hdr_ext_clear();
 
-		read_de(src, &magic, 4);
+		read_de(src, &magic, 4, sizeof(magic));
 
 		if (magic!=DACT_MAGIC_NUMBER) {
 			dact_ui_status(DACT_UI_LVL_GEN, "Bad DACT magic, checking others...");
@@ -687,21 +684,21 @@ uint32_t dact_process_file(const int src, const int dest, const int mode, const
 		read(src, &version[0], 1);
 		read(src, &version[1], 1);
 		read(src, &version[2], 1);
-		read_de(src, &filesize, 4);
-		read_de(src, &blk_cnt, 4);
-		read_de(src, &DACT_BLK_SIZE, 4);
+		read_de(src, &filesize, 4, sizeof(filesize));
+		read_de(src, &blk_cnt, 4, sizeof(blk_cnt));
+		read_de(src, &DACT_BLK_SIZE, 4, sizeof(DACT_BLK_SIZE));
 		read(src, &file_opts, 1);
-		read_de(src, &file_extd_size, 4);
+		read_de(src, &file_extd_size, 4, sizeof(file_extd_size));
 
 
 
 		while (file_extd_read<file_extd_size) {
 			x=0;
 			read(src, &ch, 1);
-			if (ch!=DACT_HDR_NOP) read_de(src, &x, 2); 
+			if (ch!=DACT_HDR_NOP) read_de(src, &x, 2, sizeof(x)); 
 			switch (ch) {
 				case DACT_HDR_CRC0:
-					read_de(src, &crcs[2], 4);
+					read_de(src, &crcs[2], 4, sizeof(crcs[2]));
 					if (crcs[4]!=0 && crcs[2]!=crcs[4]) {
 						dact_ui_status(DACT_UI_LVL_GEN, "CRC error.");
 						if (!options[DACT_OPT_NOCRC])
@@ -709,7 +706,7 @@ uint32_t dact_process_file(const int src, const int dest, const int mode, const
 					}
 					break;
 				case DACT_HDR_CRC1:
-					read_de(src, &crcs[3], 4);
+					read_de(src, &crcs[3], 4, sizeof(crcs[3]));
 					if (crcs[5]!=0 && crcs[3]!=crcs[5]) {
 						dact_ui_status(DACT_UI_LVL_GEN, "CRC error.");
 						if (!options[DACT_OPT_NOCRC])
@@ -753,7 +750,7 @@ XXX: Todo, make this do something...
 					free(hdr_buf);
 					break;
 				case DACT_HDR_CIPHER:
-					read_de(src,&cipher,x);
+					read_de(src,&cipher,x,sizeof(cipher));
 					break;
 				case DACT_HDR_NOP:
 					x=-2;
@@ -799,13 +796,13 @@ XXX: Todo, make this do something...
 			if (lseek_net(src, 1, SEEK_SET)==1) { /* MAJOR BUG HERE! was: lseek(src,1,SEEK_SET)==0 which will always be false. */
 				canlseek=1;
 				lseek_net(src, -8, SEEK_END);
-				read_de(src, &magic, 4);
+				read_de(src, &magic, 4, sizeof(magic));
 				if (magic!=DACT_MAGIC_PEOF) {
 					dact_ui_status(DACT_UI_LVL_GEN, "File is corrupt.");
 					return(0);
 				}
-				read_de(src, &filesize, 4);
-				lseek_net(src, 24+file_extd_size, SEEK_SET);
+				read_de(src, &filesize, 4, sizeof(filesize));
+				lseek_net(src, DACT_HDR_REG_SIZE+file_extd_size, SEEK_SET);
 			} else {
 				canlseek=0;
 			}
@@ -834,7 +831,7 @@ XXX: Todo, make this do something...
 			if (read(src, &algo, 1)==0) break;
 			if (algo==0xff) break; /* 0xff is reserved for EOF */
 
-			read_de(src, &blksize, blksize_size);
+			read_de(src, &blksize, blksize_size, sizeof(blksize));
 
 			if ((in_buf=malloc(blksize))==NULL) {
 				PERROR("malloc");
@@ -927,15 +924,15 @@ XXX: Todo, make this do something...
 
 
 	if (mode==DACT_MODE_STAT) {
-		read_de(src, &magic, 4);
+		read_de(src, &magic, 4, sizeof(magic));
 		read(src, &version[0], 1);
 		read(src, &version[1], 1);
 		read(src, &version[2], 1);
-		read_de(src, &filesize, 4);
-		read_de(src, &blk_cnt, 4);
-		read_de(src, &DACT_BLK_SIZE, 4);
+		read_de(src, &filesize, 4, sizeof(filesize));
+		read_de(src, &blk_cnt, 4, sizeof(blk_cnt));
+		read_de(src, &DACT_BLK_SIZE, 4, sizeof(DACT_BLK_SIZE));
 		read(src, &file_opts, 1);
-		read_de(src, &file_extd_size, 4);
+		read_de(src, &file_extd_size, 4, sizeof(file_extd_size));
 
 		printf("File              :   %s\n", filename);
 		printf("Magic             :   0x%08x",magic);
@@ -948,8 +945,8 @@ XXX: Todo, make this do something...
 
 		if (filesize==0) {
 			lseek_net(src, -8, SEEK_END);
-			read_de(src, &magic, 4);
-			read_de(src, &filesize, 4);
+			read_de(src, &magic, 4, sizeof(magic));
+			read_de(src, &filesize, 4, sizeof(filesize));
 			if (magic!=DACT_MAGIC_PEOF) {
 				PRINTERR("Bad magic, corrupt stream.");
 				return(0);
@@ -963,18 +960,18 @@ XXX: Todo, make this do something...
 		printf("Compressed Size   :   %i\n", fileoutsize);
 		printf("Uncompressed Size :   %i\n", filesize);
 		printf("Ratio             :   %2.3f to 1.0\n", ((float) filesize)/((float) fileoutsize) );
-		lseek_net(src, 24, SEEK_SET);
+		lseek_net(src, DACT_HDR_REG_SIZE, SEEK_SET);
 		while (file_extd_read<file_extd_size) {
 			x=0;
 			read(src, &ch, 1);
-			if (ch!=DACT_HDR_NOP) read_de(src, &x, 2); 
+			if (ch!=DACT_HDR_NOP) read_de(src, &x, 2, sizeof(x)); 
 			switch (ch) {
 				case DACT_HDR_CRC0:
-					read_de(src, &crcs[2], 4);
+					read_de(src, &crcs[2], 4, sizeof(crcs[2]));
 					printf("CRC 0             :   0x%08x\n", crcs[2]);
 					break;
 				case DACT_HDR_CRC1:
-					read_de(src, &crcs[3], 4);
+					read_de(src, &crcs[3], 4, sizeof(crcs[3]));
 					printf("CRC 1             :   0x%08x\n", crcs[3]);
 					break;
 		 		case DACT_HDR_NAME:
@@ -1016,7 +1013,7 @@ XXX: Todo, make this do something...
 					free(hdr_buf);
 					break;
 				case DACT_HDR_CIPHER:
-					read_de(src, &cipher, x);
+					read_de(src, &cipher, x, sizeof(cipher));
 					printf("Ciphered using    :   %s\n", ciphers_name[cipher]);
 					break;
 				case DACT_HDR_NOP:
