@@ -45,7 +45,7 @@ int write_de(const int dst, const uint32_t num, const int sze) {
 	return(x);
 }
 
-int read_de(const int src, void *dest, const int sze) {
+int read_de(const int src, void *dest, const int sze, const int out_sze) {
 	unsigned char ch;
 	uint32_t ret=0;
 	int i;
@@ -58,6 +58,6 @@ int read_de(const int src, void *dest, const int sze) {
 		ret|=ch<<(8*(sze-i-1));
 	}
 
-	memcpy(dest, &ret, sze);
+	memcpy(dest, &ret, out_sze);
 	return(sze);
 }
