@@ -1,6 +1,23 @@
 /*
-	Insert GPL Here.
-*/
+ * Copyright (C) 2001  Roy Keene
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *
+ *      email: dact@rkeene.org
+ */
+
 
 #include "module.h"
 #ifdef HAVE_LIBDL
@@ -29,6 +46,9 @@ int init_modules (void) {
 
 int unload_modules (void) {
 	int i;
+
+	if (modules_initialized==0) return(DACT_MOD_FAIL);
+
 	for (i=0;i<256;i++) {
 		if (modules[i]!=NULL)
 			dlclose(modules[i]);
