@@ -1,3 +1,23 @@
+/*
+ * Copyright (C) 2001  Roy Keene
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *
+ *      email: dact@rkeene.org
+ */
+
 /*
 	Help, my atoi() is broken.
 */
@@ -138,7 +158,7 @@ char *parse_url_subst(const char *src, const char *fname) {
 			case 346290: /* OSVR-done */
 				if (strlen(system_info.release)>127) break;
 				for (x=0;x<strlen(system_info.release);x++) {
-					if (isdigit(system_info.release[x]) || system_info.release[x]=='.') {
+					if (isdigit((int) system_info.release[x]) || system_info.release[x]=='.') {
 						ret[0]=system_info.release[x];
 						ret++;
 					} else {
@@ -151,7 +171,7 @@ char *parse_url_subst(const char *src, const char *fname) {
 				for (x=0;x<strlen(system_info.release);x++) {
 					if (system_info.release[x]=='.' && found) break;
 					if (system_info.release[x]=='.') found=1;
-					if (isdigit(system_info.release[x]) || found) {
+					if (isdigit((int) system_info.release[x]) || found) {
 						ret[0]=system_info.release[x];
 						ret++;
 					}
